==> haskell-unicode-show-0.1.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.2
id: unicode-show-0.1.0.2-IVkDXod6s6BHY2GMt397QQ
key: unicode-show-0.1.0.2-IVkDXod6s6BHY2GMt397QQ
license: BSD3
copyright: 2016 Takayuki Muranushi
maintainer: muranushi@gmail.com
homepage: http://github.com/nushio3/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/nushio3/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
author: Takayuki Muranushi
exposed: True
indefinite: False
exposed-modules:
    Text.Show.Unicode
abi: b106d1af7ad45d49da4761d4b8f83441
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unicode-show-0.1.0.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/unicode-show-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/unicode-show-0.1.0.2
hs-libraries: HSunicode-show-0.1.0.2-IVkDXod6s6BHY2GMt397QQ
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.0.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.2
id: unicode-show-0.1.0.2-FzBXl9LQy8m5GC3mfJLcvX
key: unicode-show-0.1.0.2-FzBXl9LQy8m5GC3mfJLcvX
license: BSD3
copyright: 2016 Takayuki Muranushi
maintainer: muranushi@gmail.com
homepage: http://github.com/nushio3/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/nushio3/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
author: Takayuki Muranushi
exposed: True
indefinite: False
exposed-modules:
    Text.Show.Unicode
abi: eeb63b1f09c1363e784444d73681d214
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/unicode-show-0.1.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/unicode-show-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/unicode-show-0.1.0.2
hs-libraries: HSunicode-show-0.1.0.2-FzBXl9LQy8m5GC3mfJLcvX
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
